@@ -5,52 +5,25 @@ Licensed under a 3-clause BSD style license - see LICENSE.rst
 
 """
 import math
-from distutils.version import LooseVersion
-
 import numpy as np
 from astropy.modeling import Model, Parameter
 from astropy.modeling.models import AffineTransformation2D, Identity
 from astropy import coordinates as coord
 from astropy import units as u
-
-try:
-    import gwcs
-    if LooseVersion(gwcs.__version__) > '0.12.0':
-        from gwcs.geometry import CartesianToSpherical, SphericalToCartesian
-        _GWCS_VER_GT_0P12 = True
-    else:
-        _GWCS_VER_GT_0P12 = False
-except (ImportError, ModuleNotFoundError):
-    _GWCS_VER_GT_0P12 = False
-
-if _GWCS_VER_GT_0P12:
-    _S2C = SphericalToCartesian(name='s2c', wrap_lon_at=180)
-    _C2S = CartesianToSpherical(name='c2s', wrap_lon_at=180)
-
-else:
-    def _S2C(phi, theta):
-        phi = np.deg2rad(phi)
-        theta = np.deg2rad(theta)
-        cs = np.cos(theta)
-        x = cs * np.cos(phi)
-        y = cs * np.sin(phi)
-        z = np.sin(theta)
-        return x, y, z
-
-    def _C2S(x, y, z):
-        h = np.hypot(x, y)
-        phi = np.rad2deg(np.arctan2(y, x))
-        theta = np.rad2deg(np.arctan2(z, h))
-        return phi, theta
-
-
+import gwcs
+from gwcs.geometry import CartesianToSpherical, SphericalToCartesian
 from tweakwcs.tpwcs import TPWCS, JWSTgWCS
 
 
+_S2C = SphericalToCartesian(name='s2c', wrap_lon_at=180)
+_C2S = CartesianToSpherical(name='c2s', wrap_lon_at=180)
+
+
 class DummyTPWCS(TPWCS):
-    def set_correction(self, matrix=[[1, 0], [0, 1]], shift=[0, 0], meta=None,
-                       **kwargs):
-        super().set_correction(matrix=matrix, shift=shift, meta=meta, **kwargs)
+    def set_correction(self, matrix=[[1, 0], [0, 1]], shift=[0, 0],
+                       ref_tpwcs=None, meta=None, **kwargs):
+        super().set_correction(matrix=matrix, shift=shift,
+                               ref_tpwcs=ref_tpwcs, meta=meta, **kwargs)
 
     def det_to_world(self, x, y):
         return super().det_to_world(x, y)
