@@ -6,29 +6,13 @@ Licensed under a 3-clause BSD style license - see LICENSE.rst
 """
 import copy
 import pytest
-from distutils.version import LooseVersion
 
 import numpy as np
 from astropy.modeling.models import Scale, Identity
 from astropy import wcs as fitswcs
-
-try:
-    import gwcs
-    if LooseVersion(gwcs.__version__) > '0.12.0':
-        from gwcs.geometry import SphericalToCartesian
-        _GWCS_VER_GT_0P12 = True
-    else:
-        _GWCS_VER_GT_0P12 = False
-except ImportError:
-    _GWCS_VER_GT_0P12 = False
-
-import astropy
-if LooseVersion(astropy.__version__) >= '4.0':
-    _ASTROPY_VER_GE_4 = True
-    from astropy.modeling import CompoundModel
-else:
-    _ASTROPY_VER_GE_4 = False
-
+from astropy.modeling import CompoundModel
+import gwcs
+from gwcs.geometry import SphericalToCartesian
 from tweakwcs.linearfit import build_fit_matrix
 from tweakwcs import tpwcs
 
@@ -37,7 +21,6 @@ from .helper_tpwcs import (make_mock_jwst_wcs, make_mock_jwst_pipeline,
 
 
 _ATOL = 100 * np.finfo(np.array([1.]).dtype).eps
-_NO_JWST_SUPPORT = not (_ASTROPY_VER_GE_4 and _GWCS_VER_GT_0P12)
 
 
 def test_tpwcs():
@@ -65,13 +48,15 @@ def test_tpwcs():
     assert tpwcs.meta['pytest'] == 'ABC.TPWCS'
 
     with pytest.raises(TypeError) as arg_err:
-        tpwcs.set_correction(matrix, shift, {'pytest': 'ABC.TPWCS'},
+        tpwcs.set_correction(matrix, shift, None, {'pytest': 'ABC.TPWCS'},
                              'some_weird_arg')
-    assert (arg_err.value.args[0] == "set_correction() takes from 1 "
-            "to 4 positional arguments but 5 were given")
+    assert (
+        arg_err.value.args[0].endswith(
+            "set_correction() takes from 1 to 5 positional arguments but 6 were given"
+        )
+    )
 
 
-@pytest.mark.skipif(_NO_JWST_SUPPORT, reason="requires gwcs>=0.12.1")
 def test_mock_jwst_gwcs():
     w = make_mock_jwst_wcs(v2ref=123, v3ref=500, roll=115, crpix=[-512, -512],
                            cd=[[1e-5, 0], [0, 1e-5]], crval=[82, 12])
@@ -79,7 +64,6 @@ def test_mock_jwst_gwcs():
     assert np.allclose(w.invert(*w(23, 1023)), (23, 1023))
 
 
-@pytest.mark.skipif(_NO_JWST_SUPPORT, reason="requires gwcs>=0.12.1")
 @pytest.mark.parametrize('crpix, cd', [
     (np.zeros(3), np.diag(np.ones(3))),
     (np.zeros((2, 2)), np.diag(np.ones(2))),
@@ -95,7 +79,6 @@ def test_mock_wcs_fails(crpix, cd):
         create_V2V3ToDet(v2ref=123, v3ref=500, roll=15, crpix=crpix, cd=cd)
 
 
-@pytest.mark.skipif(_NO_JWST_SUPPORT, reason="requires gwcs>=0.12.1")
 def test_v2v3todet_roundtrips():
     s2c = (Scale(1.0 / 3600.0) & Scale(1.0 / 3600.0)) | SphericalToCartesian(wrap_lon_at=180)
 
@@ -144,7 +127,6 @@ def test_v2v3todet_roundtrips():
     )
 
 
-@pytest.mark.skipif(_NO_JWST_SUPPORT, reason="requires gwcs>=0.12.1")
 def test_jwst_wcs_corr_applied(mock_jwst_wcs):
     w = make_mock_jwst_wcs(
         v2ref=123.0, v3ref=500.0, roll=115.0, crpix=[512.0, 512.0],
@@ -159,7 +141,6 @@ def test_jwst_wcs_corr_applied(mock_jwst_wcs):
     assert 'dummy_meta' in wc.meta
 
 
-@pytest.mark.skipif(_NO_JWST_SUPPORT, reason="requires gwcs>=0.12.1")
 def test_jwst_wcs_corr_are_being_combined(mock_jwst_wcs):
     wc = tpwcs.JWSTgWCS(
         mock_jwst_wcs, {'v2_ref': 123.0, 'v3_ref': 500.0, 'roll_ref': 115.0}
@@ -188,7 +169,6 @@ def test_jwst_wcs_corr_are_being_combined(mock_jwst_wcs):
     assert np.max(np.abs(tp_corr['tp_affine'].translation.value)) < _ATOL
 
 
-@pytest.mark.skipif(_NO_JWST_SUPPORT, reason="requires gwcs>=0.12.1")
 def test_jwstgwcs_unsupported_wcs():
     from tweakwcs import tpwcs
     dummy_wcs = gwcs.wcs.WCS(Identity(2), 'det', 'world')
@@ -196,7 +176,6 @@ def test_jwstgwcs_unsupported_wcs():
         tpwcs.JWSTgWCS(dummy_wcs, {})
 
 
-@pytest.mark.skipif(_NO_JWST_SUPPORT, reason="requires gwcs>=0.12.1")
 def test_jwstgwcs_inconsistent_ref(mock_jwst_wcs):
     wc = tpwcs.JWSTgWCS(
         mock_jwst_wcs, {'v2_ref': 123.0, 'v3_ref': 500.0, 'roll_ref': 115.0},
@@ -209,7 +188,6 @@ def test_jwstgwcs_inconsistent_ref(mock_jwst_wcs):
         )
 
 
-@pytest.mark.skipif(_NO_JWST_SUPPORT, reason="requires gwcs>=0.12.1")
 def test_jwstgwcs_wrong_tpcorr_type(mock_jwst_wcs):
     wc = tpwcs.JWSTgWCS(
         mock_jwst_wcs, {'v2_ref': 123.0, 'v3_ref': 500.0, 'roll_ref': 115.0},
@@ -217,7 +195,7 @@ def test_jwstgwcs_wrong_tpcorr_type(mock_jwst_wcs):
     wc.set_correction()
     p = wc.wcs.pipeline
 
-    np = [(v[0], create_V2V3ToDet()) if v[0].name == 'v2v3vacorr'
+    np = [(v.frame, create_V2V3ToDet()) if v.frame.name == 'v2v3vacorr'
           else v for v in p]
     mangled_wc = gwcs.wcs.WCS(np)
 
@@ -227,7 +205,6 @@ def test_jwstgwcs_wrong_tpcorr_type(mock_jwst_wcs):
         )
 
 
-@pytest.mark.skipif(_NO_JWST_SUPPORT, reason="requires gwcs>=0.12.1")
 def test_jwstgwcs_ref_angles_preserved(mock_jwst_wcs):
     wc = tpwcs.JWSTgWCS(
         mock_jwst_wcs, {'v2_ref': 123.0, 'v3_ref': 500.0, 'roll_ref': 115.0},
@@ -239,7 +216,6 @@ def test_jwstgwcs_ref_angles_preserved(mock_jwst_wcs):
 # Test inputs with different shapes
 
 
-@pytest.mark.skipif(_NO_JWST_SUPPORT, reason="requires gwcs>=0.12.1")
 @pytest.mark.parametrize('inputs', [[500, 512, 12, 24],
                                     [[500, 500], [512, 512], [12, 12], [24, 24]],
                                     [[[500, 500], [500, 500]],
@@ -258,7 +234,6 @@ def test_jwstgwcs_detector_to_world(inputs):
     assert np.allclose(wc.world_to_det(ra, dec), (x, y), atol=_ATOL)
 
 
-@pytest.mark.skipif(_NO_JWST_SUPPORT, reason="requires gwcs>=0.12.1")
 @pytest.mark.parametrize('inputs', [[0, 0, 12, 24],
                                     [[0, 0], [0, 0], [12, 12], [24, 24]],
                                     [[[0, 0], [0, 0]],
@@ -277,7 +252,6 @@ def test_jwstgwcs_tangent_to_world(inputs):
     assert np.allclose(wc.tanp_to_world(tanp_x, tanp_y), (ra, dec), atol=_ATOL)
 
 
-@pytest.mark.skipif(_NO_JWST_SUPPORT, reason="requires gwcs>=0.12.1")
 @pytest.mark.parametrize('inputs', [[500, 512, 0, 0],
                                     [[500, 500], [512, 512], [0, 0], [0, 0]],
                                     [[[500, 500], [500, 500]],
@@ -296,7 +270,6 @@ def test_jwstgwcs_detector_to_tanp(inputs):
     assert np.allclose(wc.tanp_to_det(tanp_x, tanp_y), (x, y), atol=_ATOL)
 
 
-@pytest.mark.skipif(_NO_JWST_SUPPORT, reason="requires gwcs>=0.12.1")
 def test_jwstgwcs_bbox():
     w = make_mock_jwst_wcs(
         v2ref=0.0, v3ref=0.0, roll=0.0, crpix=[500.0, 512.0],
@@ -322,7 +295,6 @@ def test_jwstgwcs_bbox():
     assert wc.bounding_box is None
 
 
-@pytest.mark.skipif(_NO_JWST_SUPPORT, reason="requires gwcs>=0.12.1")
 def test_jwstgwcs_bad_pipelines_no_vacorr():
     p0 = make_mock_jwst_pipeline(
         v2ref=0.0, v3ref=0.0, roll=0.0, crpix=[500.0, 512.0],
@@ -384,7 +356,6 @@ def test_jwstgwcs_bad_pipelines_no_vacorr():
         tpwcs.JWSTgWCS(w, {'v2_ref': 0.0, 'v3_ref': 0.0, 'roll_ref': 0.0})
 
 
-@pytest.mark.skipif(_NO_JWST_SUPPORT, reason="requires gwcs>=0.12.1")
 def test_jwstgwcs_bad_pipelines_with_vacorr():
     p0 = make_mock_jwst_pipeline(
         v2ref=0.0, v3ref=0.0, roll=0.0, crpix=[500.0, 512.0],
