@@ -11,30 +11,15 @@ of ``WCS``.
 import logging
 from copy import deepcopy
 from abc import ABC, abstractmethod
-from distutils.version import LooseVersion
 
 import numpy as np
-import astropy
-
-try:
-    import gwcs
-    if LooseVersion(gwcs.__version__) > '0.12.0':
-        from gwcs.geometry import CartesianToSpherical, SphericalToCartesian
-        _GWCS_VER_GT_0P12 = True
-    else:
-        _GWCS_VER_GT_0P12 = False
-except ImportError:
-    _GWCS_VER_GT_0P12 = False
-
-if LooseVersion(astropy.__version__) >= '4.0':
-    _ASTROPY_VER_GE_4 = True
-    from astropy.modeling import CompoundModel
-    from astropy.modeling.models import (
-        AffineTransformation2D, Scale, Identity, Mapping, Const1D,
-        RotationSequence3D
-    )
-else:
-    _ASTROPY_VER_GE_4 = False
+import gwcs
+from gwcs.geometry import CartesianToSpherical, SphericalToCartesian
+from astropy.modeling import CompoundModel
+from astropy.modeling.models import (
+    AffineTransformation2D, Scale, Identity, Mapping, Const1D,
+    RotationSequence3D
+)
 
 from .linalg import inv
 from . import __version__  # noqa: F401
@@ -594,19 +579,6 @@ class JWSTgWCS(TPWCS):
             Dictionary that will be merged to the object's ``meta`` fields.
 
         """
-        if not _ASTROPY_VER_GE_4:
-            raise NotImplementedError(
-                "JWST support requires astropy version >= 4.0"
-            )
-
-        if not _GWCS_VER_GT_0P12:
-            raise NotImplementedError(
-                "JWST support requires gwcs version > 0.12.0 "
-                "To pip install minimal required version, do the following:\n"
-                "pip install git+https://github.com/spacetelescope/gwcs@"
-                "1c1cb3bb35caddef80fb760ea68bc71e189d32de"
-            )
-
         valid, message = self._check_wcs_structure(wcs)
         if not valid:
             raise ValueError("Unsupported WCS structure: {}".format(message))
@@ -886,7 +858,9 @@ class JWSTgWCS(TPWCS):
 
             idx_v2v3 = frms.index(self._v23name)
             pipeline = deepcopy(self._wcs.pipeline)
-            pf, pt = pipeline[idx_v2v3]
+            step = pipeline[idx_v2v3]
+            pf = step.frame
+            pt = step.transform
             pipeline[idx_v2v3] = (pf, deepcopy(self._tpcorr))
             frm_v2v3corr = deepcopy(pf)
             frm_v2v3corr.name = 'v2v3corr'
